=======
Credits
=======

Development Lead
----------------

* Alexandra Kapp <alexandra.kapp@htw-berlin.de>
* Saskia Nuñez von Voigt <saskia.nunezvonvoigt@tu-berlin.de>
* Julia Hansmeyer <julia.hansmeyer.jgh@gmail.com>

Contributors
------------

None yet. Why not be the first?
